# dutil

A few data utilities to make life of a data scientist easier


## Installation

```shell
pip install dutil
```

## Modules

- `jupyter` (tools for jupyter notebooks)
- `pipeline` (data caching and pipelines)
- `stats` (statistical functions)
- `transform` (data transformations)